==> synce-kde_0.7.3.orig.tar.gz: synce-kde-0.7.3/raki/syncthread.h <==
/***************************************************************************
 * Copyright (c) 2003 Volker Christian <voc@users.sourceforge.net>         *
 *                                                                         *
 * Permission is hereby granted, free of charge, to any person obtaining a *
 * copy of this software and associated documentation files (the           *
 * "Software"), to deal in the Software without restriction, including     *
 * without limitation the rights to use, copy, modify, merge, publish,     *
 * distribute, sublicense, and/or sell copies of the Software, and to      *
 * permit persons to whom the Software is furnished to do so, subject to   *
 * the following conditions:                                               *
 *                                                                         *
 * The above copyright notice and this permission notice shall be included *
 * in all copies or substantial portions of the Software.                  *
 *                                                                         *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS *
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF              *
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  *
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY    *
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,    *
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE       *
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.                  *
 ***************************************************************************/

#ifndef _SYNCTHREAD_H_
#define _SYNCTHREAD_H_

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "workerthreadinterface.h"

class SyncTaskListItem;

/**
 * 
 * Volker Christian,,,
 **/
 
#define postSyncThreadEvent(a, b) \
    syncThread->postEvent((void *(WorkerThreadInterface::*) \
    (void *data = NULL)) &a, (void *) b, WorkerThreadInterface::noBlock);

class SyncThread : public WorkerThreadInterface
{
public:
    SyncThread();
    ~SyncThread();
    void incTotalSteps(void *inc);
    void decTotalSteps(void *dec);
    void advanceProgress(void *);
    void setTotalSteps(void *steps);
    void setProgress(void *progress);
    void setTask(void *task);
    void setActualSyncItem(SyncTaskListItem *actualSyncItem);

private:
    SyncTaskListItem *actualSyncItem;
};

#endif

==> synce-kde_0.8.1.1.orig.tar.gz: synce-kde-0.8.1.1.orig/raki/syncthread.h <==
/***************************************************************************
 * Copyright (c) 2003 Volker Christian <voc@users.sourceforge.net>         *
 *                                                                         *
 * Permission is hereby granted, free of charge, to any person obtaining a *
 * copy of this software and associated documentation files (the           *
 * "Software"), to deal in the Software without restriction, including     *
 * without limitation the rights to use, copy, modify, merge, publish,     *
 * distribute, sublicense, and/or sell copies of the Software, and to      *
 * permit persons to whom the Software is furnished to do so, subject to   *
 * the following conditions:                                               *
 *                                                                         *
 * The above copyright notice and this permission notice shall be included *
 * in all copies or substantial portions of the Software.                  *
 *                                                                         *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS *
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF              *
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  *
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY    *
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,    *
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE       *
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.                  *
 ***************************************************************************/

#ifndef _SYNCTHREAD_H_
#define _SYNCTHREAD_H_

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "workerthreadinterface.h"

class SyncTaskListItem;

/**
 * 
 * Volker Christian,,,
 **/
 
#define postSyncThreadEvent(a, b) \
    syncThread->postEvent((void *(WorkerThreadInterface::*) \
    (void *data)) &a, (void *) b, WorkerThreadInterface::noBlock);

class SyncThread : public WorkerThreadInterface
{
public:
    SyncThread();
    ~SyncThread();
    void incTotalSteps(void *inc);
    void decTotalSteps(void *dec);
    void advanceProgress(void *);
    void setTotalSteps(void *steps);
    void setProgress(void *progress);
    void setTask(void *task);
    void setActualSyncItem(SyncTaskListItem *actualSyncItem);

private:
    SyncTaskListItem *actualSyncItem;
};

#endif
